==> com.liferay.layout.content.page.editor.web-2.0.74.jar: META-INF/resources/page_editor/app/selectors/selectCanUpdatePageStructure.js <==
Liferay.Loader.define("layout-content-page-editor-web@2.0.74/page_editor/app/selectors/selectCanUpdatePageStructure", ['module', 'exports', 'require', '../config/constants/viewportSizes'], function (module, exports, require) {
  var define = undefined;
  var global = window;
  {
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports["default"] = selectCanUpdatePageStructure;

    var _viewportSizes = require("../config/constants/viewportSizes");

    /**
     * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
     *
     * This library is free software; you can redistribute it and/or modify it under
     * the terms of the GNU Lesser General Public License as published by the Free
     * Software Foundation; either version 2.1 of the License, or (at your option)
     * any later version.
     *
     * This library is distributed in the hope that it will be useful, but WITHOUT
     * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
     * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
     * details.
     */

    /**
     * @param {{ permissions: import("../../types/ActionKeys").ActionKeysMap, selectedViewportsize: string }} state
     */
    function selectCanUpdatePageStructure(_ref) {
      var permissions = _ref.permissions,
          selectedViewportSize = _ref.selectedViewportSize;
      return !permissions.LOCKED_SEGMENTS_EXPERIMENT && permissions.UPDATE && selectedViewportSize === _viewportSizes.VIEWPORT_SIZES.desktop;
    }
    //# sourceMappingURL=selectCanUpdatePageStructure.js.map
  }
});
//# sourceMappingURL=selectCanUpdatePageStructure.js.map

==> com.liferay.layout.content.page.editor.web-2.0.122.jar: META-INF/resources/page_editor/app/selectors/selectCanUpdatePageStructure.js <==
Liferay.Loader.define("layout-content-page-editor-web@2.0.122/page_editor/app/selectors/selectCanUpdatePageStructure", ['module', 'exports', 'require', '../config/constants/viewportSizes'], function (module, exports, require) {
  var define = undefined;
  var global = window;
  {
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = selectCanUpdatePageStructure;

    var _viewportSizes = require("../config/constants/viewportSizes");

    /**
     * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
     *
     * This library is free software; you can redistribute it and/or modify it under
     * the terms of the GNU Lesser General Public License as published by the Free
     * Software Foundation; either version 2.1 of the License, or (at your option)
     * any later version.
     *
     * This library is distributed in the hope that it will be useful, but WITHOUT
     * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
     * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
     * details.
     */

    /**
     * @param {{ permissions: import("../../types/ActionKeys").ActionKeysMap, selectedViewportsize: string }} state
     */
    function selectCanUpdatePageStructure(_ref) {
      var permissions = _ref.permissions,
          selectedViewportSize = _ref.selectedViewportSize;
      return !permissions.LOCKED_SEGMENTS_EXPERIMENT && permissions.UPDATE && selectedViewportSize === _viewportSizes.VIEWPORT_SIZES.desktop;
    }
    //# sourceMappingURL=selectCanUpdatePageStructure.js.map
  }
});
//# sourceMappingURL=selectCanUpdatePageStructure.js.map
